.. README.rst
.. ==========
..
.. Copying
.. -------
..
.. Copyright (c) 2020 none authors and contributors.
..
.. This file is part of the *none* project.
..
.. None is a free software project. You can redistribute it and/or
.. modify it following the terms of the MIT License.
..
.. This software project is distributed *as is*, WITHOUT WARRANTY OF ANY
.. KIND; including but not limited to the WARRANTIES OF MERCHANTABILITY,
.. FITNESS FOR A PARTICULAR PURPOSE and NONINFRINGEMENT.
..
.. You should have received a copy of the MIT License along with
.. *none*. If not, see <http://opensource.org/licenses/MIT>.

.. image:: https://circleci.com/gh/spack971/none.svg
  :alt: CircleCI status
  :target: https://circleci.com/gh/spack971/none


none
====

In the beginning there was none, and then bang a bunch of extra batteries
started to fill the Python universe.

*None* is an extensive Python library offering a range of extra facilities not
found in the `Python Standard Library
<https://docs.python.org/3/library/index.html>`_.


Licensing
---------

This software project is provided under the licensing terms of the
MIT License stated in the file ``LICENSE.rst``.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
